@@ -19,20 +19,11 @@ CONFIG['BASE']['manual'] = 'manual'
 CONFIG['API'] = {}
 CONFIG['API']['tcc'] = 'tcc'
 CONFIG['API']['pro'] = 'pro'
+CONFIG['API']['em'] = 'em'
 CONFIG['API']['mm'] = 'mm'
 CONFIG['API']['db'] = 'db'
 CONFIG['API']['dvs'] = 'dvs'
 
-CONFIG['EM'] = {}
-CONFIG['EM']['698'] = 'em_698'
-CONFIG['EM']['645'] = 'em_645'
-CONFIG['EM']['dlms'] = 'em_dlms'
-
-CONFIG['PRO'] = {}
-CONFIG['PRO']['gw698'] = 'gw698'
-CONFIG['PRO']['dlms'] = 'dlms'
-CONFIG['PRO']['dlt645'] = 'dlt645'
-
 CONFIG['RABBITMQ'] = {}
 CONFIG['RABBITMQ']['host'] = IP
 CONFIG['RABBITMQ']['port'] = '5672'
